@@ -42,7 +42,6 @@ class CrmLead(models.Model):
 
         for lead in self:
 
-
             if self.env['crm.team'].search([('proposal_form_submission_id','=',lead.id), ('map_id','=',default_ce_map_id)]):
                 raise UserError(
                     _("There is an allready existing Map Place related to this Lead: {}.").format(lead.name))
@@ -87,9 +86,6 @@ class CrmLead(models.Model):
 
             if m_dict.get('partner_map_place_form_url',False) and m_dict['partner_map_place_form_url']:
                 place_creation_data['external_link_url'] = m_dict['partner_map_place_form_url']
-            else:
-                raise UserError(
-                    _("Unable to get the External Link URL (mandatory map place field) from Lead: {} (metadata key: partner_map_place_form_url)").format(lead.name))
 
             place_creation_data['address_txt'] = lead._get_address_txt() or None
             place_creation_data['filter_mids'] = [(6,0,lead._get_cmfilter_ids())]
@@ -101,6 +97,7 @@ class CrmLead(models.Model):
             place._get_slug_id()
             place._get_config_relations_attrs()
             place._build_presenter_metadata_ids()
+            place.place_category_id = place_creation_data['place_category_id']
 
             place.message_subscribe([self.env.user.partner_id.id])
 
@@ -202,6 +199,17 @@ class CrmLead(models.Model):
                 raise UserError(
                     _("The Foundation Date value {} have a non valid format. It must be: yyyy-mm-dd or dd-mm-yyyy or yyyy/mm/dd or dd/mm/yyyy").format(m_dict['partner_foundation_date']))
 
+        initial_share_amount = 0.00
+        if m_dict.get('partner_initial_share_amount',False) and m_dict['partner_initial_share_amount'] or None:
+            try:
+                initial_share_amount = float(m_dict['partner_initial_share_amount'])
+            except:
+                pass
+
+        lang_id = None
+        if m_dict.get('partner_language',False) and m_dict['partner_language'] or None:
+            lang_id = self.env['res.lang'].search([('code','=',m_dict['partner_language'])],limit=1)
+
 
         create_vals = {
                 'name': self.name,
@@ -221,7 +229,10 @@ class CrmLead(models.Model):
                 'social_telegram': m_dict.get('partner_telegram',False) and m_dict['partner_telegram'] or None,
                 'create_user': True,
                 'foundation_date': foundation_date,
+                'initial_subscription_share_amount': initial_share_amount,
+                'default_lang_id': lang_id and lang_id.id or None,
             }
+
         return create_vals
 
 
